Index: webrtc/p2p/client/basicportallocator.cc |
diff --git a/webrtc/p2p/client/basicportallocator.cc b/webrtc/p2p/client/basicportallocator.cc |
index 549d013a255bb54b2a42c472dcfe1d1612413c26..2e5bc0d06c90cca9c4d1dc80f3f5e4d9f2d2ae56 100644 |
--- a/webrtc/p2p/client/basicportallocator.cc |
+++ b/webrtc/p2p/client/basicportallocator.cc |
@@ -47,7 +47,7 @@ const int PHASE_SSLTCP = 3; |
const int kNumPhases = 4; |
// Gets protocol priority: UDP > TCP > SSLTCP. |
int GetProtocolPriority(cricket::ProtocolType protocol) { |
switch (protocol) { |
case cricket::PROTO_UDP: |
@@ -55,6 +55,7 @@ int GetProtocolPriority(cricket::ProtocolType protocol) { |
case cricket::PROTO_TCP: |
return 1; |
case cricket::PROTO_SSLTCP: |
+ case cricket::PROTO_TLS: |
return 0; |
default: |
RTC_NOTREACHED(); |
@@ -47,7 +47,7 @@ const int PHASE_SSLTCP = 3; |
const int kNumPhases = 4; |
-// Gets protocol priority: UDP > TCP > SSLTCP. |
+// Gets protocol priority: UDP > TCP > SSLTCP == TLS. |
int GetProtocolPriority(cricket::ProtocolType protocol) { |
switch (protocol) { |